/*!
  Filename: verizon.tm

  Discussion: This file specifies the theme properties for the MeidaFLO 
  client's default theme. This theme is designed to match the default
  theme supported by the View Framework.

  The views that start with 'F' (e.g., FTextView) are view classes that
  are supported by the View Framework.  Refer to framewrok.tm for the
  descriptions of the framework views, as well as for their default
  properties.

  The views that start with 'MF' (e.g., MFGridView) are view classes that
  are specific to the MediaFLO client UI. All the views are sub-classes
  of the framework views, thus inherit the properties of their ancestors.

  The following is an at-a-glance view of the view hierarchy used
  by the MediaFLO client UI, including the framework views.

  Note that the properties specified for a view class, are not inherited by
  sub-classes.

  -------------------------- 
  View Classes
  -------------------------- 

  FView
     FScrollBarView
     FImageView
   	FScrollBarCornerView
     FProgressBarView
     FTextView
     FCompoundView
        FSplashView
        FScrolledView
        FScrolledTextView
        FListView
        FButtonView
           FCheckBoxView
           FToggleButtonView
           FRadioButtonView
	   MFServiceToggleView
        FRootView 
           FMainScrenView
           FDialogView
              FInfoDialogView
              FWarningDialogView
              FErrorDialogView
              FQuestionDialogView
              FProgressDialogView
              MFDescDialogView	
              MFGoToDayDialogView
              MFSelectionDialogView
              MFAboutDialog
           FMenuView
           FSoftKeyAreaView
        FMenuItemView
           MFPrefsMenuItemView
        MFChannelView
        MFGuideChannelView
        MFGuideGridView
        MFCenterPlayerControlsView
        MFProgramView
     MFGuideRulerView
     XMediaView

  The views that start with the '#' symbol you find below are specific
  instances of a particular view class. Therefore, unless overridden,
  they inherit the properties of their ancestors. Properties specified
  for these views are only applied for those instances.

  The following is a list of view instances used in the theme file.
  To specify properties of these views, refer to the view properties
  of their classes.

  --------------------------   ---------------------
  View name                    View class
  --------------------------   ---------------------
  #EULATextView                FScrolledTextView
  #channelDownArrow            FToggleButtonView
  #channelListView             FListView
  #channelNames                FCompoundView
  #channelSurfArrows           FCompoundView
  #channelUpArrow              FToggleButtonView
  #currentChannelName          FTextView 
  #dialogBackdrop              FRootView
  #elapsedTimeHolder           FCompoundView
  #elapsedTimeProgressBar      FImageProgressBarView
  #elapsedTimeText             FTextView
  #elapsedTimeTotalTimeText    FTextView
  #extraTextView               FTextView
  #fastForwardButton           FToggleButtonView 
  #fastRewindButton            FToggleButtonView
  #fullScreenPlayerInfo        FCompoundView
  #fullScreenProgramInfo       FCompoundView
  #fullScreenChannelName       FTextView
  #fullScreenProgramTitle      FTextView
  #fullScreenProgramRating     FTextView
  #guideDateHolder             FTextView
  #guideRulerBackground        FCompoundView
  #guideRulerView              MFGuideRulerView
  #guideScreenView             FCompoundView
  #guideTopHolder              FCompoundView
  #nextChannelName             FTextView
  #notificationTitleView       FTextView
  #playPauseStopButton         FToggleButtonView
  #playerControlsHolder        FCompoundView
  #playerControlsView          MFCenterPlayerControlsView
  #playerMediaView             XMedia
  #prefsMainMenuList           FListView
  #prefsRadioButtonView        FRadioButtonView 
  #prefsScreenView             FRootView
  #prefsTitleView              FTextView
  #previousChannelName         FTextView
  #programDetailsHolder        FCompoundView
  #programInfoHolder           FCompoundView
  #programRating               FTextView
  #programTitle                FTextView
  #ratingAndProgressHolder     FCompoundView
  #splashScreen                FSplashView
  #subscriptionAddOnHeader     FTextView
  #subscriptionAddOnList       FListView
  #subscriptionChargeHolder    FCompoundView
  #subscriptionChargeLabel     FTextView
  #subscriptionChargeTotal     FTextView
  #subscriptionPkgHolder       FCompoundView
  #subscriptionScreenView      FCompoundView
  #subscriptionTitleView       FTextView
  #termsOfUseView              FCompoundView
*/

#auxTheme { 
   aux_theme: "black.tm"; 
}

#extrasOptionsIcon {
   image:      "verizon.bar:extra_icon";
   blend_mode: 18;
   bg_visible: 0;
}

/******************************************************************************

 Framework views

******************************************************************************/

/*
 * Change the default font and colors for FTextView and FTextAreaView
 * to the VZW's default style.
 */
FTextView, FTextAreaView { 
   bg_visible:              1;
   font:                    "Qualcomm,18";
   text_color:              #000000;
   text_color_highlighted:  #ffffff; 
   bg_color:                #ffffff;
   highlight_color:         #000000;
}

FScrolledTextView > FScrollBarView { 
   vscroll_bg_top:        "verizon.bar:vzw_vscroll_bg_top"; 
   vscroll_bg_main:       "verizon.bar:vzw_vscroll_bg_main"; 
   vscroll_bg_bottom:     "verizon.bar:vzw_vscroll_bg_bottom"; 
   vscroll_slider_top:    "verizon.bar:vzw_vscroll_slider_top"; 
   vscroll_slider_main:   "verizon.bar:vzw_vscroll_slider_main"; 
   vscroll_slider_center: "verizon.bar:vzw_vscroll_slider_main"; 
   vscroll_slider_bottom: "verizon.bar:vzw_vscroll_slider_bottom"; 
}

FMenuView { 
   border_visible:      1;
   border_color:        #CC0000;
   bg_image:            "verizon.bar:vzw_menu_bg";
   center_tile:         "0,70,20,80";   
}

FMenuItemView > FTextView {
   bg_image_visible:             0;
   bg_visible:                   1;
   offsets:			"2,0,2,0";
   text_margins:                "4,4,4,4";
   font:                        "Qualcomm,18,B";
   bg_blend_mode:                16;
   bg_color:                     #ffffff;
   text_color:                   #000000;
   highlight_color:              #000000;
   text_color_highlighted:       #ffffff;
}

FSoftKeyAreaView {
   size:                        "0,25";
   bg_image:                    "verizon.bar:vzw_sk_bg";
   center_tile:                 "13,3,163,8";
   menu_indicator_visible:      0;
   resize_softkeys:             1;
}

/*
  Soft 1
*/

#soft1 {
   offsets:                     "3,3,0,3";
   size:                        "80,10";
   h_align:                     16;
   text_margins:                "8,0,0,1";
   bg_visible:                  1;
   bg_image:                    "verizon.bar:vzw_sk_left_btn";
   bg_image_highlight:          "verizon.bar:vzw_sk_left_btn";
   center_tile:                 "20,2,40,4";
 }

FSoftKeyAreaView > FButtonView > FTextView { 
   font:                   "Qualcomm,18,B"; 
   text_color:             #ffffff;
   text_color_highlighted: #ffffff;
   bg_visible:             0;
}

#softIconTray {
   offsets:                "0,4,3,2";
}

/*
  Soft 2
*/

#soft2 {
   size:                        "60,10";
   offsets:                     "0,3,3,3";
   h_align:                     64;
   text_margins:                "0,0,8,1";
   bg_visible:                  1;
   bg_image:                    "verizon.bar:vzw_sk_right_btn";
   bg_image_highlight:          "verizon.bar:vzw_sk_right_btn";
   center_tile:                 "20,2,40,4";
}

FScrollBarView {
   vscroll_bg_top:        "verizon.bar:vzw_vscroll_bg_top"; 
   vscroll_bg_main:       "verizon.bar:vzw_vscroll_bg_main"; 
   vscroll_bg_bottom:     "verizon.bar:vzw_vscroll_bg_bottom"; 
   vscroll_slider_top:    "verizon.bar:vzw_vscroll_slider_top"; 
   vscroll_slider_main:   "verizon.bar:vzw_vscroll_slider_main"; 
   vscroll_slider_center: "verizon.bar:vzw_vscroll_slider_main"; 
   vscroll_slider_bottom: "verizon.bar:vzw_vscroll_slider_bottom"; 

   hscroll_bg_left:       "framework.bar:hscroll_bg_left";
   hscroll_bg_main:       "framework.bar:hscroll_bg_main_r";
   hscroll_bg_right:      "framework.bar:hscroll_bg_right";
   hscroll_slider_left:   "framework.bar:hscroll_slider_left";
   hscroll_slider_main:   "framework.bar:hscroll_slider_main_r";
   hscroll_slider_center: "framework.bar:hscroll_slider_center";
   hscroll_slider_right:  "framework.bar:hscroll_slider_right";
}

/* Dialog Title View */

FDialogTitleView {
   size:                   "0,20"; 
   bg_visible:             0;
}

FDialogTitleView > FTextView { 
   offsets:         "0,0,0,0";
   bg_visible:      0;
   bg_color:        #00ff00;
   size:            "0,20"; 
   h_align:         32;
   v_align:         512;
   text_margins:    "2,0,2,0";
   font:            "Qualcomm,18,B"; 
   text_color:      #000000; 
}

/* Message dialog override */

FMessageDialogView {
   border_visible:          0;
   bg_visible:              1;
   bg_image:                "verizon.bar:vzw_dialog_bg";
   center_tile:             "50,72,100,73";
}

FMessageDialogView > FCompoundView {
   bg_visible:   0;
}

FMessageDialogView > FCompoundView >  FScrolledTextView > FTextAreaView { 
   font:          "Qualcomm,18";    
   offsets:       "0,0,0,0";
   text_margins:  "0,0,0,0";
   text_color:    #000000;
   bg_visible:    0;
}

/* Info dialog override */

FInfoDialogView {
   border_visible:          0;
   bg_visible:              1;
   bg_image:                "verizon.bar:vzw_dialog_bg";
   center_tile:             "50,72,100,73";
}

FInfoDialogView > FDialogTitleView {
   size:            "0,25"; 
}

FInfoDialogView > FDialogTitleView > FTextView { 
   offsets:         "0,10,0,0";
   h_align:         32;
   v_align:         1024;
}

FInfoDialogView > FCompoundView {
   bg_visible:      0; 
}

FInfoDialogView > FCompoundView >  FScrolledTextView > FTextAreaView { 
   font:          "Qualcomm,18";    
   offsets:       "0,0,0,0";
   text_margins:  "0,0,0,0";
   text_color:    #000000;
   bg_visible:    0;
}

/* Warning dialog override */

FWarningDialogView {
   border_visible:          0;
   bg_visible:              1;
   bg_image:                "verizon.bar:vzw_dialog_bg";
   center_tile:             "50,72,100,73";
}

FWarningDialogView > FDialogTitleView {
   bg_visible:      0;
   size:            "0,25"; 
}

FWarningDialogView > FDialogTitleView > FTextView { 
   bg_visible:      0;
   size:            "0,25";
   offsets:         "0,0,0,0";
   h_align:         32;
   v_align:         1024;
}

FWarningDialogView > FCompoundView {
   bg_visible:             0; 
   border_visible:         0;
}

FWarningDialogView > FCompoundView >  FScrolledTextView > FTextAreaView { 
   font:          "Qualcomm,18";    
   offsets:       "0,0,0,0";
   text_margins:  "0,0,0,0";
   text_color:    #000000;
   bg_visible:    0;
}

/* Question dialog override */

FQuestionDialogView {
   size:                    "200,124";
   border_visible:          0;
   bg_visible:              1;
   bg_image:                "verizon.bar:vzw_dialog_bg";
   center_tile:             "50,72,100,73";
}

FQuestionDialogView > FDialogTitleView {
   size:            "0,25"; 
   bg_visible:      0;
}

FQuestionDialogView > FDialogTitleView > FTextView { 
   bg_visible:      0;
   offsets:         "0,10,0,0";
   h_align:         32;
   v_align:         1024;
}

FQuestionDialogView > FCompoundView {
   bg_visible:      0; 
   bg_color:        #e6e6e6;
}

FQuestionDialogView > FCompoundView >  FScrolledTextView > FTextAreaView { 
   font:          "Qualcomm,18";    
   offsets:       "0,0,0,0";
   text_margins:  "0,0,0,0";
   text_color:    #000000;
   bg_visible:    0;
}

/* Error dialog override */

FErrorDialogView {
   size:                    "200,124";
   border_visible:          0;
   bg_visible:              1;
   bg_image:                "verizon.bar:vzw_dialog_bg";
   center_tile:             "50,72,100,73";
}

FErrorDialogView > FDialogTitleView {
   bg_visible:      0;
   size:            "0,25"; 
}

FErrorDialogView > FDialogTitleView > FTextView { 
   bg_visible:      0;
   offsets:         "0,10,0,0";
   h_align:         32;
   v_align:         1024;
}

FErrorDialogView > FCompoundView {
   bg_visible:      0; 
   bg_color:        #e6e6e6;
}

FErrorDialogView > FCompoundView >  FScrolledTextView > FTextAreaView { 
   font:          "Qualcomm,18";    
   offsets:       "0,0,0,0";
   text_margins:  "0,0,0,0";
   text_color:    #000000;
   bg_visible:    0;
}

/* Progress dialog override */

FProgressDialogView {
   border_visible:          0;
   bg_visible:              1;
   bg_image:                "verizon.bar:vzw_dialog_bg";
   center_tile:             "50,72,100,73";
}

FProgessDialogView > FDialogTitleView {
   bg_visible:      0;
   size:            "0,25"; 
}

FProgressDialogView > FDialogTitleView > FTextView { 
   bg_visible:      0;
   size:            "0,25";
   offsets:         "0,0,0,0";
   h_align:         32;
   v_align:         1024;
}

FProgressDialogView > FCompoundView {
   bg_visible:      0; 
   bg_color:        #e6e6e6;
}

FProgressDialogView > FCompoundView >  FScrolledTextView { 
   offsets:             "15,5,15,35";
   bg_visible:          0;
}

FProgressDialogView > FCompoundView >  FScrolledTextView > FTextAreaView { 
   font:          "Qualcomm,18";    
   offsets:       "0,0,0,0";
   text_margins:  "0,0,0,0";
   text_color:    #000000;
   bg_visible:    0;
}

/* FBusyDialogView */

FBusyDialogView {
   border_visible:          0;
   bg_visible:              1;
   bg_image:                "verizon.bar:vzw_dialog_bg";
   center_tile:             "50,72,100,73";
}

FBusyDialogView > FDialogTitleView {
   bg_visible:      0;
   size:            "0,25"; 
}

FBusyDialogView > FDialogTitleView > FTextView { 
   bg_visible:      0;
   offsets:         "0,10,0,0";
   h_align:         32;
   v_align:         1024;
}

FBusyDialogView > FCompoundView >  FScrolledTextView > FTextAreaView { 
   font:          "Qualcomm,18";    
   offsets:       "0,0,0,0";
   text_margins:  "0,0,0,0";
   text_color:    #000000;
   bg_visible:    0;
}

/* ConfirmDialogview */

FConfirmDialogView {
   border_visible:          0;
   bg_visible:              1;
   bg_image:                "verizon.bar:vzw_dialog_bg";
   center_tile:             "50,72,100,73";
}

FConfirmDialogView > FCompoundView {
   bg_visible:     0; 
   bg_color:       #e6e6e6;	
}

FConfirmDialogView > FCompoundView > FScrolledTextView > FTextAreaView { 
   font:          "Qualcomm,18";    
   offsets:       "0,0,0,0";
   text_margins:  "0,0,0,0";
   v_align:       512;
   text_color:    #000000;
   bg_visible:    0;
}

/*************************
 FMenuDialogView
 *************************/

/*!
 Name: FMenuDialogView
 Description: A generic dialog for holding list of FMenuDialogItemViews.

 Hierarchy:
 FMenuDialogView ----------> The dialog view
   FDialogTitleView -------> The title of the dialog
   FCompoundView ----------> The main area of the dialog
     FTextAreaView --------> The information text view of the dialog
     FListView ------------> The list view holding the menu items

 Properties: See FDialogView, and sub views below.
*/

FMenuDialogView > FDialogTitleView {
   size:                "0,26";
   bg_visible:           1;
   bg_image:            "verizon.bar:vzw_title_bg";
   center_tile:         "110,0,130,26";
}

FMenuDialogView > FDialogTitleView > FTextView { 
   size:            "0,26";
   h_align:          32;
   v_align:          512;
   text_margins:    "2,2,2,3";
   font:            "Qualcomm,18,B";
   text_color:      #ffffff;
}

FMenuDialogView > FCompoundView > FListView {
  spacing:        0;
}

FMenuDialogView > FCompoundView > FListView > FScrolledView {
  offsets: "0,0,0,0";
}

FMenuDialogView > FCompoundView {
   bg_color:        #ffffff;
   bg_image:        "verizon.bar:vzw_guide_list_bg";
   center_tile:     "50,20,100,40";
   bg_visible:      1;
}

FMenuDialogView > FCompoundView > FTextAreaView {
 border_visible:        0;
 font:                  "Qualcomm,18";
}

FMenuDialogItemView {
  offsets:            "0,0,0,0";
  size:               "0,32";
  bg_visible:         1;
  bg_blend_mode:      18;
  bg_image:           "verizon.bar:vzw_menu_dialog_item_bg";
  bg_image_highlight: "verizon.bar:vzw_menu_dialog_item_bg_hl";
  center_tile:        "37,8,82,17";
}

FMenuDialogItemView > FTextView {
  size:            "0,32";
  text_margins:    "6,5,4,5";
  v_align:         512;
  bg_visible:      0;
  font:            "Qualcomm,18";
  text_color:      #000000;
}

FRadioButtonView {
  deselected_image_enabled: "verizon.bar:radiobutton_unselected_a"; 
  selected_image_enabled:   "verizon.bar:radiobutton_selected_a"; 
  offsets:                  "0,0,0,0";
  size:                     "0,32";
  bg_visible:               1;
  bg_blend_mode:            18;
  bg_image:                 "verizon.bar:vzw_menu_dialog_item_bg";
  bg_image_highlight:       "verizon.bar:vzw_menu_dialog_item_bg_hl";
  center_tile:              "37,8,82,17";
}

FRadioButtonView > FTextView {
  size:                   "0,32";
  v_align:                512;
  bg_visible:             0;
  font:                   "Qualcomm,18";
  text_color:             #000000;
  text_color_highlighted: #ffffff;
}

#progressDialogProgressImage {
   size:                "20,20";
   image:               "verizon.bar:vzw_progress_animation";
   animation:           "strip,4,20,4";
}

#dialogBackdrop { 
   bg_visible:      1; 
   bg_color:        #000000cc; 
   bg_blend_mode:   17; 
}
/*   bg_color:        #0000004c;  */

/******************************************************************************
 Application Specific Views

 The application specific views are grouped based on the UI screens:

 1. Splash Screen
 2. Program Guide UI
 3. Subscription UI
 4. Player UI
 5. Preferences UI
 6. Notifications UI
 7. Parental Control UI
 8. Data Services UI

 ******************************************************************************/

/*************************
 1. Splash screen
 *************************/

/*!
 Name: #splashScreen 

 Description: The splash screen image

 Properties: 
  splash_image: "<resource file>:<resource name>" 
*/
#splashScreen { 
   splash_image: "verizon.bar:splash"; 
}

/*************************
 2. Program Guide  UI
 *************************/

/*!
 Name: MFGuideGridView

 Description: The base container of the MFChannelView. The
 MFGuideGridView contains a viewport, which contains a
 FCompoundView. The actual container of MFChannelsView is the
 FCompoundView (i.e., MFGuideGridView > FViewport > FCompoundView).

 Properties: See FCompoundView.  

*/
MFGuideGridView { 
   size:            "138,0"; 
   border_visible:  0; 
   bg_visible:          1;
   bg_image:            "verizon.bar:vzw_guide_bg";
   center_tile:         "50,20,100,40";
}

/*!
 Name: MFGuideGridView > FViewport > FCompoundView

 Description: The actual container of the MFChannelsView.
 
 Properties: See FCompoundView.
*/
MFGuideGridView > FViewport > FCompoundView { 
   bg_visible:               0;
}

/*************************
 Guide Empty Message
 *************************/

#guideMessageHolder {
   bg_visible:      0;
}

#guideMessage {
   text_margins:	   "5,5,5,5";
   text_color:             #303030; 
   font:                   "Qualcomm,18,B"; 
   bg_visible:      0;
}

#guideMessageIcon {
   size:                "20,20";
   image:               "verizon.bar:vzw_progress_animation";
   animation:           "strip,4,20,4";
}

/*************************
 MFChannelView
 *************************/

/*!
 Name: MFChannelView

 Description: The container of MFProgramViews.
 
 Properties: See FCompoundView.
*/
MFChannelView { 
   border_visible:  0; 
   bg_visible:      0;
}

/*************************
 MFProgramView
 *************************/

/*!
 Name: MFProgramView

 Description: The view used to display individual programs in the guide.

 Properties: 
   scheduled_at_icon    "<resource file>:<resource name>" 

  (See FCompoundView for other properties.)
*/
MFProgramView  { 
   playable_icon:               "verizon.bar:playable_check"; 
   playerror_icon:              "verizon.bar:playable_error"; 
   alternate_content_icon:      "verizon.bar:alternate_content"; 
   bg_visible:                  0;
   bg_image:                    "verizon.bar:vod_shadow_bg";
   center_tile:                 "5,5,35,13";
   vod_title_color:             #990000;
}

/*!
 Name: MFProgramView > FCompoundView

 Description: The actual container of the title txt and the extra info.
 
 Properties: See FCompoundView.

*/
MFProgramView > FCompoundView { 
   offsets:                             "0,0,0,0";
   bg_blend_mode:                       18;
   bg_image:                            "verizon.bar:vzw_guide";
   bg_image_highlight:                  "verizon.bar:vzw_guide_hl";
   center_tile:                         "40,15,80,30";
}

/*!
 Name: MFProgramView > FCompoundView > FTextView

 Description: The program title text.
 
 Properties: See FTextView.
*/
MFProgramView > FCompoundView > FTextView {
   text_margins:	   "3,2,0,0";
   text_color:             #303030; 
   text_color_highlighted: #ffffff;
   font:                   "Qualcomm,18,B"; 
   bg_visible:             0; 
}

/*!
 Name: MFProgramView > FCompoundView > FCompoundView

 Description: The holder of extra information: icon(s) and the program
 description.
 
 Properties: See FCompoundView.  
*/
MFProgramView > FCompoundView > FComoundView {
   bg_visible:             0; 
}

/*!
 Name: MFProgramView > FCompoundView > FCompoundView > FTextView

 Description: The program description text.
 
 Properties: See FTextView.
*/
MFProgramView > FCompoundView > FCompoundView > FTextView {
   text_margins:	   "3,1,0,4";
   font:                   "Qualcomm,18"; 
   text_color:             #303030; 
   text_color_highlighted: #ffffff;
   bg_visible:             0; 
}

/*!
 Name: MFProgramView > FCompoundView > FCompoundView > FImageView

 Description: The visual property of the scheduled_at_icon used in the
 2nd line of the MFProgramView.  The icon is specified in
 MFProgramView.

 Properties: See FImageView.  
*/
MFProgramView > FCompoundView > FCompoundView > FImageView { 
   offsets:      "4,3,0,0";
   blend_mode:   18;
   bg_visible:   0;
}

/*!
 Name #guideScreenView

 Description: The base holder of all the guide UI views. This view is
 used to specify a background image for the entire Guide.  Make sure
 to make views in front of this view transparent or translucent. It is
 not used by the default theme.

 Properties: *See FCompoundView for properties 
*/
/*
#guideScreenView {
   bg_image:          "verizon.bar:bg_image";
   bg_visible:        1;
}
*/

/*!
 Name #guideTopHolder

 Description: Holds the views at the top of the guide including the date
 and the guide ruler.

 Properties: *See FCompoundView for properties 
*/
#guideTopHolder {
   bg_image:            "verizon.bar:vzw_date_bg";
   center_tile:         "30,2,44,18";
}

/*!
 Name: #guideDateHolder

 Description: The view that displays the date in the Guide UI.
 
 Properties: See FTextView.
*/
#guideDateHolder { 
   offsets:             "0,2,0,2";
   size:                "60,0"; 
   font:                "Qualcomm,18"; 
   text_color:          #ffffff;
   text_margins:        "2,0,2,0";
   h_align:             32;
   v_align:             512;
   bg_visible:          0;
}

/*!
 Name: #guideRulerBackground

 Description: The background of the guide ruler
 
 Properties: See FCompoundView.
*/
#guideRulerBackground {
   bg_visible:          0;
}

/*!
 Name: #guideRulerView

 Description: The background of the guide ruler.

 Properties: 
   font                <fontname>  // QUALCOMM's font format
   text_color          <color>     // #rrggbg[aa]
   mark_color          <color>     // #rrggbg[aa]

   ruler_left_arrow    "<resource file>:<resource name>"
   ruler_right_arrow   "<resource file>:<resource name>"
   ruler_maker         "<resource file>:<resource name>"

   (FView for other properties.)
*/
#guideRulerView {
   offsets:                "0,2,2,2";
   text_margins:  	   "7,0,0,0";
   mark_color:             #ff7777;
   text_color:             #303030;
   font:                   "Qualcomm,18";
   blend_mode:             18;
   ruler_left_arrow:       "verizon.bar:vzw_guide_ruler_left_arrow";
   ruler_right_arrow:      "verizon.bar:vzw_guide_ruler_right_arrow";
   ruler_marker:           "verizon.bar:vzw_guide_ruler_marker";
   bg_blend_mode:          16;
   bg_image:               "verizon.bar:vzw_guide_time";
   center_tile:            "4,5,16,7";
}

/*!
  Name: #guideMainHolder

  Description: This view holds the channelListView, the guideScrollBar,
  and the guideGridView.

  Properties: See FCompoundView.
*/
#guideMainHolder {
    bg_visible:   1;
    bg_color:     #e6e6e6;
}

/*!
 Name: #channelListView

 Description: The container of MFGuideChannelViews on the left side of
 the Program Guide UI. The service name must be big enougth
 to hold any 4 letter service name ex. "WWWW"

 Properties: See FListView..  
*/
#channelListView { 
   size:         "60,0";
   bg_color:     #CC0000;
   bg_visible:   1;
}

/*!
 Name: MFGuideChannelView

 Description: The list item used in the #channelListView.
 
 Properties:
   subscribed_image    "<resource file>:<resource name>"

  (See FCompoundView for other properties.)

   bg_color:          #ffbf7b;
   highlight_color:   #000000;

*/
MFGuideChannelView {
   bg_visible:                        1;
   bg_blend_mode:                     18;
   clipcast_image:                    "verizon.bar:clipcast_icon";
   streaming_image:                   "verizon.bar:streaming_icon";
   broadcast_image:                   "verizon.bar:broadcast_icon";
   audio_image:                       "verizon.bar:audio_icon";
   bg_image:                          "verizon.bar:vzw_guide_channel_bg";
   bg_image_highlight:                "verizon.bar:vzw_guide_channel_bg_hl";
   center_tile:                       "30,2,44,28";
}

#channelStatusIcon {
  size:  "12,9";
  blend_mode: 18;
}	

/*!
 Name: MFGuideChannelView > FTextView

 Description: The text view for channel names used in the guide UI.
 
 Properties: See FTextView.
*/
MFGuideChannelView > FTextView { 
   offsets:                 "0,0,0,0";
   h_align:                 32;
   v_align:                 512;
   font:                    "Qualcomm,18,B"; 
   text_color_highlighted:  #ffffff;
   text_color:              #ffffff;
   bg_visible:              0;
}

/*!
 Name: MFGuideChannelView > FImageView

 Description: Subscription Icon. The image view for the
 subscription_image used by MFGuideChannelView.

 Properties: See FImageView.  
*/
MFGuideChannelView > FImageView { 
   offsets:     "0,0,0,4";
   bg_visible:	0; 
   blend_mode:	18; 
   auto_size:   1;
}

/*************************
  Now Playing UI
 *************************/

/*!
 Name: FToggleButtonView > FImageView

 Description: A bitmap used by the FToggleButtonView.

 Properties: See FImageView.  
*/
FToggleButtonView > FImageView { 
   bg_visible:    0;
   blend_mode:    16;
}

/*************************
 MFDescDialogView
 *************************/

/*!
 Name: MFDescDialogView

 Description: A special dialog box for displaying presentation descriptions.

 Hierarchy:

 FDescDialogView ----------> The root view
   FTextView --------------> The title of the dialog
   FCompoundView ----------> The main area of the dialog
     FTextView ------------> The name of the program
     FCompoundView --------> Holds other info views
       FTextView ----------> The time and duration of a program
       FTextView ----------> A program's rating
     FScrolledView --------> Scrolls the rest of the info
       FCompoundView ------> Holder
         FCompoundView ----> Holds a note that is sometimes visible
           FTextView ------> The note text
           FTextAreaView --> The note details text
         FTextAreaView ----> A text description

 Properties: See FDialogView, and sub views below.
*/

MFDescDialogView {
  size:                 "200,124";
  offsets:              "22,1,22,2";
  bg_visible:           1;
  bg_image:             "verizon.bar:vzw_dialog_bg";
  center_tile:          "50,72,100,73";
}

MFDescDialogView > FDialogTitleView {
  size:                 "0,25"; 
}

MFDescDialogView > FDialogTitleView > FTextView { 
  bg_visible:           0;
  size:                 "0,25";
  offsets:              "0,0,0,2";
  h_align:              32;
  v_align:              1024;
}

MFDescDialogView > FCompoundView {
  bg_visible:           0;
  bg_color:             #e6e6e6;
  bg_image:             "verizon.bar:vzw_shortmsg_bg";
  center_tile:          "0,40,40,50";
}

MFDescDialogView > FCompoundView > FTextView {
  offsets:              "4,4,4,0";
  text_margins:         "8,2,5,0";
  font:                 "Qualcomm,18,B"; 
  bg_visible:           0;
}

MFDescDialogView > FCompoundView > FCompoundView {
  offsets:             "4,4,4,0";
  bg_visible:          0;
}

MFDescDialogView > FCompoundView > FCompoundView > FTextView {
 bg_visible:           0;
 font:                 "Qualcomm,18,B"; 
 text_margins:         "8,2,5,0";
}

MFDescDialogView > FCompoundView > FScrolledView {
  offsets:              "4,4,4,4";
  bg_visible:           0;
}

MFDescDialogView > FCompoundView > FScrolledView > FViewport > FCompoundView {
  bg_visible:           0;
}

MFDescDialogView > FCompoundView > FScrolledView > FViewport > FCompoundView > FCompoundView {
  bg_visible:           0;
  offsets:              "8,8,8,5";
  border_visible:       1;
  border_color:         #940000;
}

MFDescDialogView > FCompoundView > FScrolledView > FViewport > FCompoundView > FCompoundView > FTextView {
  bg_visible:           0;
  font:                 "Qualcomm,18,B"; 
  text_margins:         "8,5,5,0";
}

MFDescDialogView > FCompoundView > FScrolledView > FViewport > FCompoundView > FCompoundView > FTextAreaView {
  bg_visible:           0;
  text_margins:         "8,5,5,5";
}

MFDescDialogView > FCompoundView > FScrolledView > FViewport > FCompoundView > FTextAreaView {
  offsets:              "0,4,0,0";
  bg_visible:           0;
  text_margins:         "8,2,0,5";
}

/*************************
 MFGoToDayDialogView
 *************************/

MFGoToDayDialogView {
   size:            "155,185"; 
   offsets:         "22,1,22,2"; 
}

MFGoToDayDialogView > FDialogTitleView {
   size:            "0,25"; 
}

MFGoToDayDialogView > FDialogTitleView > FTextView { 
   bg_visible:      0;
   size:            "0,25";
   offsets:         "0,0,0,2";
   h_align:         32;
   v_align:         1024;
}

/*!
 Name: MFGoToDayDialogView

 Description: The base view of the go to day dialog box.

 Properties: See FCompoundView.
*/
MFGoToDayDialogView {
   border_visible:          0;
   bg_visible:              1;
   bg_image:                "verizon.bar:vzw_dialog_bg";
   center_tile:             "50,72,100,73";
}

/*!
 Name: MFGoToDayDialogView > FCompoundView

 Description: The container of the go to day menu.

 Properties: See FCompoundView
*/
MFGoToDayDialogView > FCompoundView {
   bg_visible:      0; 
}

MFGoToDayDialogView > FCompoundView > FScrolledView {
   bg_visible:      0; 
}

MFGoToDayDialogView > FCompoundView > FScrolledView > FViewport > {
   bg_visible:      0; 
}

MFGoToDayDialogView > FCompoundView > FScrolledView > FViewport > FCompoundView {
   bg_visible:      0; 
}

/*************************
 3. The Subscription UI
 *************************/

MFSubIntroPageView {
   bg_visible:          1;
   bg_color:            #ffffff;
}

/*!
 Name: #subsInitTitleView
 
 Description: A text title of the initial screen for subscription wizard
 
 Properties: See FTextView
*/
#subsInitTitleView {
   size:                      "0,26";
   text_margins:              "2,2,2,3";
   h_align:                   32;
   v_align:                   512;
   font:                      "Qualcomm,18,B";
   text_color:                #ffffff;
   bg_image:                  "verizon.bar:vzw_title_bg";
   center_tile:               "110,0,130,26";
}

#subsInitMenuListView {
   spacing:             "0";
   bg_visible:          1;
   bg_image:            "verizon.bar:vzw_guide_list_bg";
   center_tile:         "50,20,100,40";
}

#listScrolledView { 
   bg_visible: 0;
}

#scrollViewport {
   bg_visible: 0;
}

#listHolder {
   bg_visible: 0;
}

MFSubIntroMenuItemView {
   bg_visible:                          1; 
   bg_blend_mode:                       18;
   bg_image:                            "verizon.bar:vzw_guide";
   bg_image_highlight:                  "verizon.bar:vzw_guide_hl";
   center_tile:                         "40,15,80,30";
}  

/*!
 Name: MFSubIntroMenuItemView > FTextView

 Description: The menu item for the subscription wizard.

 Properties: See FTextView.
   
*/
MFSubIntroMenuItemView > FTextView { 
   size:                        "0,40";
   v_align:                     512;
   offsets:			"2,0,2,0";
   text_margins:                "4,4,4,4";
   font:                        "Qualcomm,18,B";
   bg_visible:                   0;
}

/*!
 Name: #subsInitInfoTextView
 
 Description: A text view displaying information on the initial screen
 
 Properties: See FTextAreaView
*/

#subsInitInfoTextView {
   size:                "0,140";
   offsets:             "3,3,3,2";
   h_align:             16;
   v_align:             512;
   font:                "Qualcomm,18";
   text_margins:        "5,5,3,3";
   border_visible:      0;
   bg_visible:          1;
   bg_color:            #ffffff;
}

/*!
 Name: #basicConfigTitleView
 
 Description: title text for basic package configuration page
 
 Properties: See FTextView
*/
#basicConfigTitleView {
   size:                      "0,26";
   text_margins:              "2,2,2,3";
   font:                      "Qualcomm,18,B";
   text_color:                #ffffff;
   h_align:                   32;
   v_align:                   512;
   bg_image:                  "verizon.bar:vzw_title_bg";
   center_tile:               "110,0,130,26";
}

/*!
 Name: MFPkgButtonView


 Description: The toggle button view for packages.
  
 Properties:
   single_unselected    "<resource file>:<resource name>"
   single_selected      "<resource file>:<resource name>"
   single_canceled      "<resource file>:<resource name>"
   selection_pending    "<resource file>:<resource name>"
   multiple_unselected    "<resource file>:<resource name>"
   multiple_selected      "<resource file>:<resource name>"
   multiple_canceled      "<resource file>:<resource name>"   
*/
MFPkgButtonView {
   bg_visible:                          0;   
   single_unselected:                   "verizon.bar:radiobutton_unselected_a";
   single_selected:                     "verizon.bar:radiobutton_selected_a";
   single_canceled:                     "verizon.bar:radiobutton_unselected_a";
   selection_pending:                   "verizon.bar:checkbox_buy_a";
   multiple_unselected:                 "verizon.bar:checkbox_unchecked_a";
   multiple_selected:                   "verizon.bar:checkbox_checked_a";
   multiple_canceled:                   "verizon.bar:checkbox_cancel_a";
   auto_selected:                       "verizon.bar:checkbox_checkonly_a";

}
/* "verizon.bar:checkbox_checkonly_a"; */

MFPkgButtonView > FImageView { 
   offsets:     "0,4,0,0";
   bg_visible:  0;
   blend_mode:  18;
}  

MFPkgButtonView > FCompoundView {
   bg_visible:  0;
}

MFPkgButtonView > FCompoundView > FTextAreaView {
   text_margins:                     "4,2,4,2";
   font:                             "Qualcomm,18"; 
   text_color:                       #000000;
   text_color_highlighted:           #1511a4;
   bg_visible:  0;
}

MFPkgButtonView > FCompoundView > FCompoundView {
   bg_visible:  0;
}

MFPkgButtonView > FCompoundView > FCompoundView > FTextView {
   offsets:                          "0,0,0,0";
   text_margins:                     "4,4,4,4";
   font:                             "Qualcomm,18"; 
   text_color:                       #000000;
   text_color_highlighted:           #1511a4;
   bg_visible:  0;
} 

#basicPkgListView {
   spacing:             "0";
   bg_visible:          1;
   bg_image:            "verizon.bar:vzw_guide_list_bg";
   center_tile:         "50,20,100,40";
}

MFBasicItemView {
   bg_visible:                          1;   
   bg_blend_mode:                       18;
   bg_color:                            #ffffff;
   highlight_color:                     #000000;  
   single_unselected:                   "verizon.bar:radiobutton_unselected_a";
   single_selected:                     "verizon.bar:radiobutton_selected_a";
   single_canceled:                     "verizon.bar:radiobutton_unselected_a";
   selection_pending:                   "verizon.bar:checkbox_buy_a";
   multiple_unselected:                 "verizon.bar:checkbox_unchecked_a";
   multiple_selected:                   "verizon.bar:checkbox_checked_a";
   multiple_canceled:                   "verizon.bar:checkbox_cancel_a";
   auto_selected:                       "verizon.bar:checkbox_checkonly_a";
   bg_image:                            "verizon.bar:vzw_guide";
   bg_image_highlight:                  "verizon.bar:vzw_guide_hl";
   center_tile:                         "40,15,80,30";
}

MFBasicItemView > FImageView { 
   offsets:     "4,8,0,4";
   bg_visible:  0;
   blend_mode:  18;
}  

MFBasicItemView > FCompoundView {
   offsets:     "0,4,0,0";
   bg_visible:  0;
}

MFBasicItemView > FCompoundView > FTextAreaView {
   text_margins:                     "4,2,4,2";
   font:                             "Qualcomm,18"; 
   text_color:                       #000000;
   text_color_highlighted:           #ffffff;
   bg_visible:                       0;
}

MFBasicItemView > FCompoundView > FCompoundView {
   bg_visible:  0;
}

MFBasicItemView > FCompoundView > FCompoundView > FTextView {
   text_margins:                     "4,4,4,4";
   font:                             "Qualcomm,18,B"; 
   text_color:                       #000000;
   text_color_highlighted:           #ffffff;
   bg_visible:                       0;
}

/*
  This is a full screen message used in the subscription ui.
*/
MFSubInfoDialogView {
   bg_visible:          1;
   bg_color:            #ffffff;
}

MFSubInfoDialogView > FDialogTitleView {
   size:                "0,26";
   bg_visible:          1;
   bg_color:            #000000;
   bg_image:            "verizon.bar:vzw_title_bg";
   center_tile:         "110,0,130,26";
}

MFSubInfoDialogView > FDialogTitleView > FTextView {
   size:                      "0,26";
   h_align:                   32;
   v_align:                   512;
   text_margins:              "2,2,2,3";
   font:                      "Qualcomm,18,B";
   text_color:                #ffffff;
}

MFSubInfoDialogView > FCompoundView {
   bg_visible: 0;
}

MFSubInfoDialogView > FCompoundView > FScrolledTextView {
   bg_visible:          1;
   bg_image:            "verizon.bar:vzw_guide_list_bg";
   center_tile:         "50,20,100,40";
   border_visible:      0;
}

MFSubInfoDialogView > FCompoundView > FScrolledTextView > FTextAreaView {
  font:            "Qualcomm,18";
  v_align:         "512";
  text_margins:    "10,10,10,0";
  bg_visible:      0;
}

/* MFSubPremiumPageView */

MFSubPremiumPageView {
   bg_visible: 0;
}

#premiumConfigTitleView {
   size:                "0,26";
   text_margins:        "2,2,2,3";
   font:                "Qualcomm,18,B";
   text_color:          #ffffff;
   h_align:             "32";
   v_align:             "512";
   bg_image:            "verizon.bar:vzw_title_bg";
   center_tile:         "110,0,130,26";
}

#premiumConfigBaseView {
  offsets:              "0,3,0,0";
  bg_visible:           0;
}

MFSubPremiumPageView > MFPkgButtonView > FCompoundView > FCompoundView > FTextView{
   font:                             "Qualcomm,18,B"; 
}

MFSubPremiumPageView > FExpandingListView {
   bg_visible:          1;
   bg_image:            "verizon.bar:vzw_guide_list_bg";
   center_tile:         "50,20,100,40";
}
/*
   single_selected:                     "verizon.bar:radiobutton_selected_a";
   multiple_selected:                   "verizon.bar:checkbox_checked_a";
   auto_selected:                       "verizon.bar:checkbox_checkonly_a";
*/
MFPremiumItemView {
   bg_visible:                          1;   
   bg_blend_mode:                       18;
   bg_color:                            #ffffff;
   highlight_color:                     #000000;
   single_unselected:                   "verizon.bar:radiobutton_unselected_a";
   single_selected:                     "verizon.bar:checkbox_buy_a";
   single_canceled:                     "verizon.bar:radiobutton_unselected_a";
   selection_pending:                   "verizon.bar:checkbox_buy_a";
   multiple_unselected:                 "verizon.bar:checkbox_unchecked_a";
   multiple_selected:                   "verizon.bar:checkbox_buy_a";
   multiple_canceled:                   "verizon.bar:checkbox_cancel_a";
   auto_selected:                       "verizon.bar:checkbox_buy_a";

   bg_image:                            "verizon.bar:vzw_guide";
   bg_image_highlight:                  "verizon.bar:vzw_guide_hl";
   center_tile:                         "40,15,80,30";
}

MFPremiumItemView > FImageView { 
   offsets: "0,9,0,0";
   bg_visible:  0;
   blend_mode:  18;
}  

MFPremiumItemView > FCompoundView {
   offsets: "0,4,0,0";
   bg_visible:  0;
}

MFPremiumItemView > FCompoundView > FTextAreaView {
   text_margins:                     "5,0,5,5";
   font:                             "Qualcomm,18"; 
   text_color:                       #ffffff;
   bg_visible:  0;
}

MFPremiumItemView > FCompoundView > FCompoundView {
   bg_visible:  0;
}

MFPremiumItemView > FCompoundView > FCompoundView > FTextView {
   text_margins:                     "5,5,5,5";
   font:                             "Qualcomm,18,B"; 
   text_color:                       #000000;
   text_color_highlighted:           #ffffff;
   bg_visible:  0;
}

MFSubEULADialogView > FDialogTitleView {
   size:                      "0,0";
   bg_visible:                1;
   bg_image:                  "verizon.bar:vzw_title_bg";
   center_tile:               "110,0,130,26";
}

MFSubEULADialogView > FDialogTitleView > FTextView {
   size:                      "0,26";
   h_align:                   32;
   v_align:                   512;
   text_margins:              "2,2,2,3";
   font:                      "Qualcomm,18,B";
   text_color:                #ffffff;
}

MFSubEULADialogView > FCompoundView > FTextAreaView {
   size:                   "220,20";
   offsets:                "0,0,0,0";
   border_visible:         0;
   bg_visible:             1;
   bg_color:               #ffffff;
   text_margins:           "10,10,10,5";
   font:                   "Qualcomm,18";
}

MFSubEULADialogView > FCompoundView > FScrolledTextView {
   offsets:                 "3,3,3,2";
   border_visible:          1;
   bg_visible:              1;
   bg_image:                "verizon.bar:vzw_guide_bg";
   center_tile:             "50,20,100,40";
   border_color:            #474747;
}

MFSubEULADialogView > FCompoundView > FScrolledTextView > FTextAreaView {
   bg_visible:    0;
   text_color:    #000000;
   text_margins:  "5,5,5,0";
   font:          "Qualcomm,18";
}

#subSingleBaseTitleView {
   size:                      "0,26";
   text_margins:              "2,2,2,3";
   font:                      "Qualcomm,18,B";
   text_color:                #ffffff;
   h_align:                   32;
   v_align:                   512;
   bg_image:                  "verizon.bar:vzw_title_bg";
   center_tile:               "110,0,130,26";
}

#subSingleBaseMsgView {
   offsets:               "0,0,0,0";
   text_margins:          "5,5,5,5";
   font:                  "Qualcomm,18";
   border_visible:         0;
   bg_visible:             1;
   bg_color:               #ffffff;
}

#subSingleBaseListView {
   spacing:             "1";
   bg_visible:          1;
   bg_image:            "verizon.bar:vzw_guide_list_bg";
   center_tile:         "50,20,100,40";
}

MFSubSingleBasePageView {
   bg_visible:          1;
   bg_image:            "verizon.bar:vzw_guide_list_bg";
   center_tile:         "50,20,100,40";
}

MFSubSingleBasePageView > FExpandingListView {
   spacing:             "0";
   bg_visible:          1;
   bg_image:            "verizon.bar:vzw_guide_list_bg";
   center_tile:         "50,20,100,40";
}

MFSubChannelView {
   bg_visible:                          1;   
   bg_blend_mode:                       18;
   bg_color:                            #ffffff;
   highlight_color:                     #000000;  
   single_unselected:                   "verizon.bar:radiobutton_unselected_a";
   single_selected:                     "verizon.bar:radiobutton_selected_a";
   single_canceled:                     "verizon.bar:radiobutton_unselected_a";
   selection_pending:                   "verizon.bar:checkbox_buy_a";
   multiple_unselected:                 "verizon.bar:checkbox_unchecked_a";
   multiple_selected:                   "verizon.bar:checkbox_checked_a";
   multiple_canceled:                   "verizon.bar:checkbox_cancel_a";
   auto_selected:                       "verizon.bar:checkbox_checkonly_a";

   bg_image:                            "verizon.bar:vzw_guide";
   bg_image_highlight:                  "verizon.bar:vzw_guide_hl";
   center_tile:                         "40,15,80,30";
}

MFSubChannelView > FCompoundView {
   offsets: "0,4,0,0";
   bg_visible:  0;
}

MFSubChannelView > FCompoundView > FTextAreaView {
   text_margins:                     "4,2,4,2";
   font:                             "Qualcomm,18"; 
   text_color:                       #ffffff;
   bg_visible:                       0;
}

MFSubChannelView > FCompoundView > FCompoundView {
   bg_visible:  0;
}

MFSubChannelView > FCompoundView > FCompoundView > FTextView {
   text_margins:                     "4,4,4,4";
   font:                             "Qualcomm,18,B"; 
   text_color:                       #000000;
   text_color_highlighted:           #ffffff;
   bg_visible:  0;
}

MFSubSettingsPageView {
   bg_visible:          1;
   bg_color:            #ffffff;
}

MFSubSettingsPageView > FTextAreaView {
   offsets:               "1,1,1,1";
   text_margins:          "5,5,5,5";
   font:                  "Qualcomm,18";
   border_visible:         0;
   bg_visible:             1;
   bg_color:               #ffffff;
}

#subSettingsTitleView {
   size:                      "0,26";
   text_margins:              "2,2,2,3";
   font:                      "Qualcomm,18,B";
   text_color:                #ffffff;
   h_align:                   32;
   v_align:                   512;
   center_tile:               "110,0,130,26";
   bg_image:                  "verizon.bar:vzw_title_bg";
}

#subSettingsListView {
   bg_visible:          1;
   bg_image:            "verizon.bar:vzw_guide_list_bg";
   center_tile:         "50,20,100,40";
}

#subSettingsBaseItemView {
   bg_visible:          1;
   bg_color:            #ffffff;
   highlight_color:     #000000;
}

MFSubSettingsPageView > MFPkgButtonView > FCompoundView > FCompoundView > FTextView {
   text_color:                       #000000;
   text_color_highlighted:           #ffffff;
}

#subSettingsBaseHeader {
   text_margins:     "0,1,0,3";
   font:             "Qualcomm,18,B";
   h_align:          32;
   v_align:          512;
   text_color:       #ffffff;
   bg_color:         #acacac;
   bg_image:         "verizon.bar:vzw_header_bg";
   center_tile:      "2,4,12,8";
   bg_visible:       1;
}

#subSettingsPremiumHeader {
   text_margins:           "0,1,0,3";
   font:                   "Qualcomm,18,B";
   h_align:                32;
   v_align:                512;
   text_color:             #ffffff;
   text_color_highlighted: #ffffff;
   bg_color:               #cacaca;
   bg_image:               "verizon.bar:vzw_header_bg";
   center_tile:            "2,4,12,8";
   bg_visible:             1;
}

#subSettingsTotalView {
   offsets:          "0,1,0,0";
   text_margins:     "2,2,2,4";
   font:             "Qualcomm,18,B";
   h_align:          64;
   v_align:          512;
   text_color:       #000000;
   bg_color:         #acacac;
   bg_visible:       1;
}

MFSubSettingsPageView > FListView > FScrolledView > FViewport > FCompoundView > MFPkgButtonView {
   bg_visible:                          1;   
   bg_color:                            #e6e6e6; 
   single_unselected:                   "verizon.bar:radiobutton_unselected_a";
   single_selected:                     "verizon.bar:radiobutton_selected_a";
   single_canceled:                     "verizon.bar:radiobutton_unselected_a";
   selection_pending:                   "verizon.bar:checkbox_buy_a";
   multiple_unselected:                 "verizon.bar:checkbox_unchecked_a";
   multiple_selected:                   "verizon.bar:checkbox_checked_a";
   multiple_canceled:                   "verizon.bar:checkbox_cancel_a";
   auto_selected:                       "verizon.bar:checkbox_checkonly_a";
   bg_image:           "verizon.bar:vzw_menu_dialog_item_bg";
   bg_image_highlight: "verizon.bar:vzw_menu_dialog_item_bg_hl";
   center_tile:        "37,8,82,17";
   bg_blend_mode:      18;
}

MFSubSettingsPageView > FListView > FScrolledView > FViewport > FCompoundView > MFPkgButtonView > FImageView { 
   offsets:     "0,5,0,0";
   bg_visible:  0;
   blend_mode:  18;
}  

MFSubSettingsPageView > FListView > FScrolledView > FViewport > FCompoundView > MFPkgButtonView > FCompoundView {
   bg_visible:  0;
}

MFSubSettingsPageView > FListView > FScrolledView > FViewport > FCompoundView > MFPkgButtonView > FCompoundView > FCompoundView > FTextView {
   text_margins:                     "5,5,5,5";
   font:                             "Qualcomm,18"; 
   text_color:                       #000000;
   text_color_highlighted:           #ffffff;
   bg_visible:                       0;
}

MFSubSettingsPageView > FListView > FScrolledView > FViewport > FCompoundView > MFPkgButtonView > FCompoundView > FCompoundView {
   bg_visible:  0;
}

MFSubSettingsPageView > FListView > FScrolledView > FViewport > FCompoundView > FMenuItemView {
   bg_color:         #e6e6e6;
   bg_visible:       1;
}

MFSubSettingsPageView > FListView > FScrolledView > FViewport > FCompoundView > FMenuItemView > FTextView { 
   text_margins:                        "5,5,5,5";
   font:                                "Qualcomm,18"; 
   text_color:                          #000000;
   text_color_highlighted:              #ffffff;
   bg_color:                            #e6e6e6; 
   bg_blend_mode:                       16;
   bg_visible:                          1;
   bg_image:                            "framework.bar:popup_transp";
   bg_image_highlight:                  "framework.bar:menu_sl_hl";
   center_tile:                         "45,7,65,9";
}

/* SubTOUPage View */

MFSubTOUPageView {
   bg_visible:          1;
   bg_color:            #ffffff;
}

MFSubTOUPageView > FTextView {
   size:                      "0,26";
   h_align:                   16;
   v_align:                   512;
   text_margins:              "2,2,2,3";
   font:                      "Qualcomm,18,B";
   text_color:                #000000;
   bg_image:                  "verizon.bar:vzw_title_bg";
   center_tile:               "110,0,130,26";
}

MFSubTOUPageView > FScrolledTextView {
   bg_visible:             0;
}

MFSubTOUPageView > FScrolledTextView > FTextAreaView {
  v_align:         "512";
  text_margins:    "10,10,10,0";
  font:            "Qualcomm,18";
  bg_visible:      0;
}

/* MFSubInfoPage View */

MFSubInfoPageView > FScrolledTextView {
   bg_visible:          1;
   border_visible:      0;
   bg_color:            #ffffff;
}

MFSubInfoPageView > FScrolledTextView > FTextAreaView {
  v_align:         "512";
  text_margins:    "10,0,10,0";
  font:            "Qualcomm,18";
  bg_visible:      0;
}

/* more info screen */

MFSubPreviewPageView {
   bg_image:            "verizon.bar:vzw_guide_list_bg";
   center_tile:         "50,20,100,40";
}

MFSubPreviewPageView > FTextView {
   size:                      "0,26";
   text_margins:              "2,2,2,3";
   font:                      "Qualcomm,18,B";
   h_align:                   32;
   v_align:                   512;
   text_color:                #ffffff;
   bg_image:                  "verizon.bar:vzw_title_bg";
   center_tile:               "188,10,228,20";
}

MFDescriptionView {
   bg_visible:          0;
}

#descriptionHeader {
   bg_visible:          1;
   bg_color:            #ffffff;
   border_visible:      "1";
   border_color:        #000000;
}

MFDescriptionView > FCompoundView > FImageView {
   auto_size:           1;
   blend_mode:          18;
   bg_visible:          0;
}

#descriptionLeftArrow {
   image:               "verizon.bar:arrow_left";
}

#descriptionRightArrow {
   image:               "verizon.bar:arrow_right";
}

#descriptionTitleView1 {
   h_align:             32;
   v_align:             512;
   text_margins:        "0,1,0,3";
   font:                "Qualcomm,18,B"; 
   text_color:          #000000;
   bg_visible:          0;
}

#descriptionTitleView2 {
   h_align:             32;
   text_margins:        "2,5,2,3";
   font:                "Qualcomm,18,B"; 
   text_color:          #ffffff;
   bg_visible:          0;
}

#descAttributesHolder {
   bg_visible:              0;
   border_visible:          0;
}

#descAttributeView1 {
   text_margins:           "10,5,5,5";
   font:                   "Qualcomm,18,B"; 
   text_color:             #000000;
   text_color_highlighted: #ffffff;
   bg_visible:             0;
}

#descAttributeView2 {
   text_margins:           "15,5,5,5";
   font:                   "Qualcomm,18,B"; 
   text_color:             #000000;
   text_color_highlighted: #ffffff;
   bg_visible:             0;
}

MFDescriptionView > FScrolledTextView {
   bg_visible:          0;
}

MFDescriptionView > FScrolledTextView > FTextAreaView {
   text_margins:        "10,0,10,0";   
   font:                "Qualcomm,18"; 
   bg_visible:          0;
}

MFChannelDescDialogView {
   bg_image:            "verizon.bar:vzw_guide_list_bg";
   center_tile:         "50,20,100,40";
   bg_visible:              1;
}

MFChannelDescDialogView > FDialogTitleView {
   bg_image:            "verizon.bar:vzw_title_bg";
   center_tile:         "110,0,130,26";
   size:                "0,0";
   bg_visible:          1;   
}

MFChannelDescDialogView > FDialogTitleView > FTextView {
   size:                      "0,26";
   h_align:                   32;
   v_align:                   512;
   text_margins:              "2,2,2,3";
   font:                      "Qualcomm,18,B";
   text_color:                #ffffff;
}

MFChannelDescDialogView > FCompoundView {
   bg_visible:             0;
}

MFSubEULAView > FTextAreaView {
   size:                   "220,20";
   offsets:                "0,0,0,0";
   border_visible:         0;
   bg_visible:             1;
   bg_image:               "verizon.bar:vzw_gradient_bg";
   text_margins:           "5,8,5,8";
   font:                   "Qualcomm,18";
}

MFSubEULAView > FScrolledTextView {
   offsets:                 "0,0,0,0";
   border_visible:          1;
   bg_visible:              1;
   border_color:            #474747;
}

MFSubEULAView > FScrolledTextView > FTextAreaView {
   font:          "Qualcomm,18";
   bg_visible:    0;
   text_color:    #000000;
   text_margins:  "5,3,5,0";
}

MFSubEULAPageView {
   bg_visible:          1;
   bg_color:            #ffffff;
}

MFSubEULAPageView > FTextView {
   size:                "0,26";
   text_margins:        "2,2,2,3";
   h_align:             32;
   v_align:             512;
   font:                "Qualcomm,18,B";
   text_color:          #ffffff;
   bg_image:            "verizon.bar:vzw_title_bg";
   center_tile:         "110,0,130,26";
}

MFSubTOUView > FTextAreaView {
   size:                "220,20";
   offsets:             "0,0,0,0";
   border_visible:      0;
   bg_visible:          1;
   bg_image:            "verizon.bar:vzw_guide_list_bg";
   center_tile:         "50,20,100,40";
   text_margins:        "5,8,5,8";
   font:                "Qualcomm,18";
}

MFSubTOUView > FCompoundView > FTextView {
   text_margins:           "0,4,0,2";
   font:                   "Qualcomm,18,B";
   text_color:             #474747;
   text_color_highlighted: #ffffff;
   bg_color:               #cacaca;
   bg_visible:             1;
}

MFSubTOUView > FCompoundView > FListView {
   bg_visible:          1;
   bg_image:            "verizon.bar:vzw_guide_bg";
   center_tile:         "50,20,100,40";
}

MFSubTOUDialogView > FDialogTitleView {
   size:                "0,0";
   bg_visible:          1;
   bg_image:            "verizon.bar:vzw_title_bg";
   center_tile:         "110,0,130,26";
}

MFSubTOUDialogView > FDialogTitleView > FTextView {
   size:                      "0,26";
   h_align:                   32;
   v_align:                   512;
   text_margins:              "2,2,2,3";
   font:                      "Qualcomm,18,B";
   text_color:                #ffffff;
}

MFSubConfirmPageView {
   bg_visible:          1;
   bg_color:            #ffffff;
}

MFSubConfirmPageView > FTextView {
   size:                "0,26";
   text_margins:        "2,2,2,3";
   h_align:             32;
   v_align:             512;
   font:                "Qualcomm,18,B";
   text_color:          #ffffff;
   bg_image:            "verizon.bar:vzw_title_bg";
   center_tile:         "110,0,130,26";
}

#buyNowPackageListView {
   spacing:             "0";
   bg_visible:          1;
   bg_image:            "verizon.bar:vzw_guide_list_bg";
   center_tile:         "50,20,100,40";
}

#buyNowTitleView {
   size:                      "0,26";
   text_margins:              "2,2,2,3";
   font:                      "Qualcomm,18,B";
   text_color:                #000000;
   bg_image:                  "verizon.bar:vzw_title_bg";
   center_tile:               "110,0,130,26";
}

#buyNowInfoTextView {
   text_margins:     "5,5,5,5";
   font:             "Qualcomm,18";
   border_visible:   1;
}

MFBuyNowItemView {
   bg_visible:                          1;   
   bg_blend_mode:                       18;
   bg_color:                            #ffffff;
   highlight_color:                     #000000;  
   single_unselected:                   "verizon.bar:radiobutton_unselected_a";
   single_selected:                     "verizon.bar:radiobutton_selected_a";
   single_canceled:                     "verizon.bar:radiobutton_unselected_a";
   selection_pending:                   "verizon.bar:checkbox_buy_a";
   multiple_unselected:                 "verizon.bar:checkbox_unchecked_a";
   multiple_selected:                   "verizon.bar:checkbox_checked_a";
   multiple_canceled:                   "verizon.bar:checkbox_cancel_a";
   auto_selected:                       "verizon.bar:checkbox_checkonly_a";
   bg_image:                            "verizon.bar:vzw_guide";
   bg_image_highlight:                  "verizon.bar:vzw_guide_hl";
   center_tile:                         "40,15,80,30";
}

MFBuyNowItemView > FImageView { 
   offsets:     "4,8,0,4";
   bg_visible:  0;
   blend_mode:  18;
}  

MFBuyNowItemView > FCompoundView {
   offsets:     "0,4,0,0";
   bg_visible:  0;
}

MFBuyNowItemView > FCompoundView > FTextAreaView {
   text_margins:                     "4,2,4,2";
   font:                             "Qualcomm,18"; 
   text_color:                       #000000;
   text_color_highlighted:           #ffffff;
   bg_visible:                       0;
}

MFBuyNowItemView > FCompoundView > FCompoundView {
   bg_visible:  0;
}

MFBuyNowItemView > FCompoundView > FCompoundView > FTextView {
   text_margins:                     "4,4,4,4";
   font:                             "Qualcomm,18,B"; 
   text_color:                       #000000;
   text_color_highlighted:           #ffffff;
   bg_visible:                       0;
}


/*************************
 4. Player UI
 *************************/

/*!
 Name: #playerScreenView

 Description: This is the top view for the regular player screen.

 Properties: See FRootView.
*/
#playerScreenView {
   bg_visible:     0;
   alpha_enabled:  1;
   full_screen:    1;
}

/*!
 Name: #topPlayerView

 Description: A view that contains the video view and any other views that
 appear in the video area.

 Properties: See FCompoundView.
*/
#topPlayerView {
   bg_visible: 0;
}

/*!
 Name: #playerMediaView

 Description: A view that contains the video.

 Properties: See XMediaView.
*/
#playerMediaView {
   bg_visible: 0;
}

/*!
 Name: #playerStatusView

 Description: The area of the player dedicated to displaying status messages
 when there is no video on the screen.

 Properties: See MFMultiMediaStatusView.
*/
#playerStatusView {
}

/*!
 Name: #playerImageView

 Description: The area of the player dedicated to displaying image information
 when image content is shown (not video).

 Properties: See FImageView.
*/
#playerImageView {
}

/*!
 Name: #playerControlsView

 Description: A view that contains the volume controls, channel info, 
 video controls, and progress info.

 Properties: 'volume_bars' is the number of volume bars to show in the volume
 indicator.  Values different from the actual number of volume levels on the
 device are allow.  If this value is left out the application will determine the
 number of bars to be used.  If 'volume_bars' is not specified the volume views
 should allow for up to seven bars.

 For other properties see FCompoundView.
*/
#playerControlsView {
   bg_visible:  0;
   size:        "0,34";
   volume_bars: 4;
}

/*!
 Name: #playerBackground

 Description: The background view for the player.  Contains the channel, 
    volume and progress info.

 Properties: See FCompoundView.
*/
#playerBackground {
    size:               "0,34";
    bg_visible:         1;
    bg_image:           "verizon.bar:player_bg";
    center_tile:        "0,11,60,22";
}

/*!
 Name: #playerSoftKeyPlaceHolder

 Description: Place holder for the soft key bar when the player controls spill
 out over the soft key bar.  Currently this is not used.

 Properties: See FCompoundView.
*/
#playerSoftKeyPlaceHolder {
   bg_visible:          0;
   size:                "0,25";
   bg_image:            "verizon.bar:vzw_sk_bg";
   center_tile:         "75,0,165,25";
}

/*!
 Name: #playerVolumeAndChannelHolder

 Description: Compound view containing the volume indicator and channel name.

 Properties: See FCompoundView.
*/
#playerVolumeAndChannelHolder {
    bg_visible: 0;
    offsets:    "4,0,0,0";
}

/*!
 Name: #playerVolumeHolder

 Description: Compound view containing the volume bars and a mute icon.

 Properties: See FCompoundView.
*/
#playerVolumeHolder {
    bg_visible: 0;
}

/*!
 Name: #playerVolumeBarHolder

 Description: Compound view containing the volume bars.  See 
 'playerControlsView' for into on setting number of volume bars displayed.

 Properties: See FCompoundView.
*/
#playerVolumeBarHolder {
    bg_visible: 0;
}

/*!
 Name: #playerVolumeBar

 Description: One volume bar in the 'playerVolumeBarHolder'.

 Properties: See FToggleButtonView.
*/
#playerVolumeBar {
    bg_visible: 0;
    toggle0_image_enabled: "verizon.bar:player_volume_bar_empty";
    toggle1_image_enabled: "verizon.bar:player_volume_bar_filled";
}

/*!
 Name: #playerMuteToggle

 Description: The volume muted indicator.

 Properties: See FToggleButtonView.
*/
#playerMuteToggle {
    bg_visible: 0;
    offsets:    "5,0,0,0";
    toggle0_image_enabled: "verizon.bar:player_audio_muted";
    toggle1_image_enabled: "verizon.bar:player_audio_unmuted";
}

/*!
 Name: #playerChannelName

 Description: The properties for the channel name are specified through this
 view.  The service name must be big enougth to hold any 4 letter service name
 ex. "WWWW".
 
 Properties: See FTextView.
*/
#playerChannelName {
   offsets:                "0,0,0,0";
   text_margins:           "8,3,0,15";
   bg_visible:             0;
   bg_color:               #ffffff;
   font:                   "Qualcomm,10,B";
   text_color:             #ffffff;
}

/* Elapsed time display */

/*!
 Name: #playerProgressBar

 Description: The progress bar for clips.

 Properties: See FImageProgressBarView for properties.
*/
#playerProgressBar {
   bg_visible:      0;
   blend_mode:      18;
   offsets:         "43,3,0,0";
   pb_left:         "verizon.bar:player_progress_left";
   pb_left_filled:  "verizon.bar:player_progress_left_filled";
   pb_center:       "verizon.bar:player_progress_center";
   pb_fill_center:  "verizon.bar:player_progress_center_filled";
   pb_right:        "verizon.bar:player_progress_right";
   pb_right_filled: "verizon.bar:player_progress_right_filled";
}

/*!
 Name: #playerProgressHolder

 Description: Compound view containing the current program progress and total
   time.

 Properties: See FCompoundView.
*/
#playerProgressHolder {
   bg_visible:   0;
   offsets:     "0,0,3,0";
}

/*!
 Name: #playerElapsedTimeText

 Description: This view draws the elapsed time string.
 
 Properties: See FTextView.
*/
#playerElapsedTimeText { 
   font:         "Qualcomm,10";
   text_color:   #ffffff;
   text_margins: "0,0,0,0";
   bg_visible:   0;
}

/*!
 Name: #playerTimeSeparator

 Description: This view draws the separator between the total time and elapsed
 time.
 
 Properties: See FTextView.
*/
#playerTimeSeparator {
   font:         "Qualcomm,10";
   text_color:   #ffffff;
   text_margins: "0,0,0,0";
   bg_visible:   0;
}

/*!
 Name: #playerTotalTimeText

 Description: This view draws the elapsed time string.
 
 Properties: See FTextView.
*/
#playerTotalTimeText {
   font:         "Qualcomm,10";
   text_color:   #ffffff;
   text_margins: "0,0,0,0";
   bg_visible:   0;
}

/*!
 Name: #fiveWayControlsHolder

 Description: This view is centered in the player controls area.  It contains
 the channel up/down, fast forward/rewind and play/pause buttons.  This view is
 a fixed size and the buttons locations are specified in offsets.

*/
#fiveWayControlsHolder {
   bg_visible:          1;
   size:                "70,60";
   bg_blend_mode:       18;
   bg_image:            "verizon.bar:player_bg_fiveway_center";
}

/*!
 Name: #channelUpArrow

 Description: The up arrow icon for channel surfing.  It's disabled when this
 function is not available and highlighted when the button is pressed.
 
 Properties: See FToggleButtonView.
*/
#channelUpArrow {
   toggle0_image_enabled: "verizon.bar:player_btn_channel_up";
   toggle1_image_enabled: "verizon.bar:player_btn_channel_up_highlight";
   toggle2_image_enabled: "verizon.bar:player_btn_channel_up_disabled";
   bg_visible:            0;
   offsets:               "25,4,0,0";
}

/*!
 Name: #channelDownArrow

 Description: The down arrow icon for channel surfing.  It's disabled when this
 function is not available and highlighted when the button is pressed.

 Properties: See FToggleButtonView.
*/
#channelDownArrow {
   toggle0_image_enabled: "verizon.bar:player_btn_channel_down";
   toggle1_image_enabled: "verizon.bar:player_btn_channel_down_highlight";
   toggle2_image_enabled: "verizon.bar:player_btn_channel_down_disabled";
   bg_visible:            0;
   offsets:               "25,41,0,0";
}

/*!
 Name: #fastRewindButton

 Description: Pressing this button plays the current video clip in the
 fast-rewind mode.  It's disabled when this function is not available and
 highlighted when the button is pressed.
 
 Properties: See FToggleButtonView.
   toggle1_image_enabled: "verizon.bar:player_btn_fastrewind_highlight";
   toggle2_image_enabled: "verizon.bar:player_btn_fastrewind_disabled";
*/
#fastRewindButton {
   toggle0_image_enabled: "verizon.bar:player_btn_fastrewind";
   toggle1_image_enabled: "verizon.bar:player_btn_fastrewind_highlight";
   toggle2_image_enabled: "verizon.bar:player_btn_fastrewind_disabled";
   bg_visible:            0;
   offsets:               "4,23,0,0";
}

/*!
 Name: #playPauseStopButton

 Description: Pressing this button plays or pauses the current video clip.
 Disabled when this function is not available and highlighted when the button
 is pressed.  The pause button is shown when watching clips or any other media
 that can be resumed from where it left off when this button was pressed.  For
 live media that can't resume from a previous position the stop button is
 displayed.
 
 Properties: See FToggleButtonView.
*/
#playPauseStopButton {
   toggle0_image_enabled: "verizon.bar:player_btn_play";
   toggle1_image_enabled: "verizon.bar:player_btn_play_highlight";
   toggle2_image_enabled: "verizon.bar:player_btn_play_disabled";
   toggle3_image_enabled: "verizon.bar:player_btn_pause";
   toggle4_image_enabled: "verizon.bar:player_btn_pause_highlight";
   toggle5_image_enabled: "verizon.bar:player_btn_pause_disabled";
   toggle6_image_enabled: "verizon.bar:player_btn_stop";
   toggle7_image_enabled: "verizon.bar:player_btn_stop_highlight";
   toggle8_image_enabled: "verizon.bar:player_btn_stop_disabled";
   bg_visible:            0;
   offsets:               "25,23,0,0";
}

/*!
 Name: #fastForwardButton

 Description: Pressing this button plays the current video in the fast forward
 mode.  It's disabled when this function is not available and highlighted when
 the button is pressed.
 
 Properties: See FToggleButtonView.
*/
#fastForwardButton { 
   toggle0_image_enabled: "verizon.bar:player_btn_fastforward";
   toggle1_image_enabled: "verizon.bar:player_btn_fastforward_highlight";
   toggle2_image_enabled: "verizon.bar:player_btn_fastforward_disabled";
   bg_visible:            0;
   offsets:               "46,23,0,0";
}

/*!
 Name: #fullScreenPlayerView

 Description: The properties for the top level view of the full screen player.

 Properties: See FRootView
*/
#fullScreenPlayerView {
   bg_visible: 0;
}

/*!
 Name: MFChannelFirstPopupView

 Description: View containing the channel/program info temporally shown when
 changing program/channels.
 alternate center_tile:         "50,9,79,10";

 Properties: See FCompoundView
*/
MFChannelFirstPopupView {
   size:                "0,20";            
   bg_visible:          1;
   bg_image:            "verizon.bar:player_popup";
   center_tile:         "3,3,21,19";
}

/*!
 Name: #playerPopupChannelName

 Description: The channel name displayed in the player popup.
 Properties: See FTextView
*/
#playerPopupChannelName {
   bg_visible:   0;
   text_color:   #333333;
   size:         "60,0";
   offsets:      "8,3,0,0";
   text_margins: "2,0,2,4";
   font:         "Qualcomm,18,B";
}

/*!
 Name: #playerPopupProgramTitle

 Description: The program name displayed in the player popup.

 Properties: See FAnimatedTextView
*/
#playerPopupProgramTitle {
   bg_visible:          0;
   font:         "Qualcomm,18,B";
   offsets:      "0,3,0,0";
   text_margins: "2,0,2,4";
   text_color:   #333333;
}

/*!
 Name: #playerPopupProgramRating

 Description: The program rating displayed in the player popup.

 Properties: See FTextView
*/
#playerPopupProgramRating {
   bg_visible:   0;
   font:         "Qualcomm,18,B";
   offsets:      "0,3,8,0";
   text_margins: "2,0,2,4";
   text_color:   #333333;
}

/*!
 Name: XMediaView

 Description: This view is the background of movies.

 Properties: 
    Icon to display when playing an audio only presentation
    audio_only_icon     "<resource file>:<resource name>"

    See FView for other properties.
*/
XMediaView {
   bg_visible:          0;
   audio_only_icon:     "verizon.bar:audio_only_icon_3";
}

/*************************
 FStatusBarView
 *************************/
/*!
 Name: FStatusBarView
 Description:  A status bar view is an area of the screen available to display
               status, usually text messages.  You'll often find one at the
	       bottom of a screen.
*/
FStatusBarView {
   border_color:     #222222;
   bg_color:         #323232;
   bg_visible:       1;
   border_visible:   1;
}

FStatusBarView > FTextAreaView {
   text_color:       #cccccc;
   font:             "Qualcomm,11";
}

/*************************
 5. The Preferences UI
 *************************/

/* Prefenreces Main Menu */

/*!
 Name: #prefsScreenView {

 Description: The base view of the preferences dialog. It is a full-screen
 dialog.

 Properties: See FCompoundView.
*/
#prefsScreenView {
    bg_visible:      1;
    bg_color:        #ffffff;
}

/*!
 Name: #prefsTitleView {

 Description: The title view for the preferences UI's main menu.

 Properties: See FTextView.
*/
#prefsTitleView {
   size:                      "0,26";
   text_margins:              "2,2,2,3";
   font:                      "Qualcomm,18,B"; 
   text_color:                #000000;
   bg_image:                  "verizon.bar:vzw_title_bg";
   center_tile:               "110,0,130,26";
}

/* Generic Preferences UI */

/*!
 Name: MFPrefsMenuItemView > FTextView

 Description: The menu item for the preferences UI.

 Properties: See FTextView.
*/
MFPrefsMenuItemView > FTextView { 
   text_margins:                     "4,5,4,5";
   font:                             "Qualcomm,18,B";
   blend_mode:                       16;
   text_color:                       #000000;
   text_color_highlighted:           #ffffff;
   bg_color:                         #ffffff;
   highlight_color:                  #000000;
}

#selectionInfoTextView {
   text_margins:                "5,5,5,5";
   font:                        "Qualcomm,18";
   border_visible:              1;
}

/*!
 Name: MFSelectionDialogView > FDialogTitleView

 Description: The title area of the MFSelectionDialogView.

 Properties: See FDialogTitleView.
*/

MFSelectionDialogView > FDialogTitleView {
   size:                  "0,0";
   bg_visible:            1;
   bg_image:              "verizon.bar:vzw_title_bg";
   center_tile:           "110,0,130,26";
}

/*!
 Name: MFSelectionDialogView > FDialogTitleView > FTextView 

 Description: The text inside the title area.

 Properties: See FTextView.
*/
MFSelectionDialogView > FDialogTitleView > FTextView { 
   size:            "0,0";
   font:            "Qualcomm,18,B";
   text_color:      #e6e6e6; 
}

/*!
 Name: MFSelectionDialogView > FCompoundView

 Description: The background of the MFSelectionDialogView.

 Properties: See FCompoundView.
*/

MFSelectionDialogView > FCompoundView {
   bg_color:        #ffffff;
   bg_visible:      1;
}

/*!
 Name: #prefsRadioButtonView

 Description: A radio button view used by MFSelectionDialogView.

 Properties:
*/
#prefsRadioButtonView {
   bg_color:                         #ffffff;
   text_color:                       #303030; 
   text_color_highlighted:           #1511a4;
   highlight_color:                  #000000;
   blend_mode:                       16;
   bg_visible:                       1;
}
/*
   bg_image_highlight:          "framework.bar:menu_sl_hl";
   center_tile:                 "45,7,65,9";

*/

/* Service Exclusion Preferences */

/*!
 Name: MFServiceToggleView

 Description: Special menu items used by MFExclusionDialogView.

 Properties:
*/
MFServiceToggleView {
   service_locked_enabled:           "verizon.bar:checkbox_locked_a";
   service_excluded_enabled:         "verizon.bar:checkbox_unchecked_a";
   service_included_enabled:         "verizon.bar:checkbox_checked_a";
   bg_color:                         #ffffff;
   highlight_color:                  #000000;
   bg_visible:                       1;
}
/*
   bg_image_highlight:          "framework.bar:menu_sl_hl";
   center_tile:                 "45,7,65,9";
*/

/*!
 Name: MFServiceToggleView > FImageView

 Description: The icon used in front of the menu item string in the
 MFExclusionDialogView.

 Properties: See FImageView.
*/
MFServiceToggleView > FImageView { 
   bg_visible:  0; 
   blend_mode:  18; 
}

/*!
 Name: MFServiceToggleView > FTextView

 Description: The menu item string used in the MFExclusionDialogView.

 Properties: See FTextView.
*/
MFServiceToggleView > FTextView { 
   text_color:    #303030; 
   font:          "Qualcomm,18"; 
   bg_visible:    0; 
}

/*!
 Name: MFExclusionDialogView > FDialogTitleView

 Description: The title area of the MFExclusionDialogView.

 Properties: See FDialogTitleView.
*/

MFExclusionDialogView > FDialogTitleView {
   size:                "0,0";
   bg_visible:          1;
   bg_image:            "verizon.bar:vzw_title_bg";
   center_tile:         "110,0,130,26";
}

/*!
 Name: MFExclusionDialogView > FDialogTitleView > FTextView 

 Description: The text inside the title area.

 Properties: See FTextView.
*/
MFExclusionDialogView > FDialogTitleView > FTextView { 
   size:            "0,0";
   font:            "Qualcomm,18,B";
   text_color:      #e6e6e6; 
}

/*!
 Name: #fullScrnPrefsRadioButtonView

 Description: A radio button view used by MFSelectionDialogView.

 Properties:
*/
#fullScrnPrefsRadioButtonView {
   blend_mode:                       16;
   bg_color:                         #ffffff;
   text_color:                       #000000;
   text_color_highlighted:           #ffffff;
   highlight_color:                  #000000;
   bg_visible:                       1;
}

/*************************
 MFImgDescRadioButtonView
 *************************/

/*!
 Name: MFImgDescRadioButtonView 

 Description: The view class for constructing radio buttons.
 Typically, the same radio button icons are used throughout the
 MediaFLO application; so those are specified at this level.

 Properties: 
   deselected_image_enabled:   "<resource file>:<resource name>"
   selected_image_enabled:     "<resource file>:<resource name>"

   (See FButtonView for other properties.)  
*/

MFImgDescRadioButtonView { 
   deselected_image_enabled:  "verizon.bar:radiobutton_unselected_a"; 
   selected_image_enabled:    "verizon.bar:radiobutton_selected_a"; 
}

/*!
 Name: MFImgDescRadioButtonView > FImageView

 Description: The images view for the MFImgDescRadioButtonView. The blend mode
 and the background visibility of the images specified in
 MFImgDescRadioButtonView are specified here. Typically, no other view
 properties are specified here.

 Properties: See FImageView.  
*/

MFImgDescRadioButtonView > FImageView { 
   blend_mode:        18; 
   bg_visible:        0; 
   border_visible:    0;
}

/*!
 Name: MFImgDescRadioButtonView > FTextView

 Description: The text properties for the MFImgDescRadioButtonView are
 specified through this view.

 Properties: See FTextView.  
*/

MFImgDescRadioButtonView > FTextView {
   size:            "40,0";
   font:            "Qualcomm,18";
   text_color:      #000000;
   bg_visible:      0; 
}

/*!
 Name: MFHotKeyDialogView

 Description: The dialog that shows hot key settings.

 Properties: 
   hotkey2_icon    "<resource file>:<resource name>"       // key '2' icon
   hotkey3_icon    "<resource file>:<resource name>"       // key '3' icon
   hotkey4_icon    "<resource file>:<resource name>"       // key '4' icon
   hotkey5_icon    "<resource file>:<resource name>"       // key '5' icon
   hotkey6_icon    "<resource file>:<resource name>"       // key '6' icon
   hotkey7_icon    "<resource file>:<resource name>"       // key '7' icon
   hotkey8_icon    "<resource file>:<resource name>"       // key '8' icon
   hotkey9_icon    "<resource file>:<resource name>"       // key '9' icon
   hotkeystar_icon "<resource file>:<resource name>"       // key '*' icon
*/
MFHotKeyDialogView {
   hotkey2_icon:        "verizon.bar:settings_skey_2";
   hotkey3_icon:        "verizon.bar:settings_skey_3";
   hotkey4_icon:        "verizon.bar:settings_skey_4";
   hotkey5_icon:        "verizon.bar:settings_skey_5";
   hotkey6_icon:        "verizon.bar:settings_skey_6";
   hotkey7_icon:        "verizon.bar:settings_skey_7";
   hotkey8_icon:        "verizon.bar:settings_skey_8";
   hotkey9_icon:        "verizon.bar:settings_skey_9";
   hotkeystar_icon:     "verizon.bar:settings_skey_star";
}

/*!
 Name: MFHotKeyDialogView > FDialogTitleView

 Description: The title area of the MFHotKeyDialogView.

 Properties: See FDialogTitleView.
*/

MFHotKeyDialogView > FDialogTitleView {
   size:                "0,0";
   bg_visible:          1;
   bg_image:            "verizon.bar:vzw_title_bg";
   center_tile:         "110,0,130,26";
}

/*!
 Name: MFHotKeyDialogView > FDialogTitleView > FTextView 

 Description: The text inside the title area.

 Properties: See FTextView.
*/
MFHotKeyDialogView > FDialogTitleView > FTextView { 
   size:            "0,0";
   font:            "Qualcomm,18,B";
   text_color:      #e6e6e6; 
}

/*!
 Name: MFHotKeyDialogView > FCompoundView

 Description: The background of the MFHotKeyDialogView.

 Properties: See FCompoundView.
*/

MFHotKeyDialogView > FCompoundView {
   bg_color:        #ffffff;
   bg_visible:      1;
}

/*!
 Name: #hotKeyInfoTextView

 Description: The text area view for the shortcut key setting information. 
 
 Properties: See FTextAreaView.
*/
#hotKeyInfoTextView {
   offsets:         "8,8,4,0";
}

#hotKeySettingImageView {
   offsets:         "4,4,4,8";
   bg_visible:      0;
   image:           "verizon.bar:settings_skey_master";
}

#hotKeyScaleToFitHolder {
   offsets:         "10,0,10,10";
}

#scaleOutImageView {
   offsets:         "5,0,5,0";
   bg_visible:      0;
   image:           "verizon.bar:settings_scale_out";
}

#scaleInImageView {
   offsets:         "5,0,5,0";
   bg_visible:      0;
   image:           "verizon.bar:settings_scale_in";
}

/*!
 Name: MFHotKeyItemView
 
 Description: The compound view for setting information of a shortcut key.
 
 Properties: See FCompoundView.
*/
MFHotKeyItemView {
   offsets:         "8,4,6,4";
}

/*!
 Name: MFHotKeyItemView > FCompoundView > FTextView

 Description: The text view for the name of a shortcut key.
 
 Properties: See FTextView.
*/
MFHotKeyItemView > FCompoundView > FTextView {
   font:            "Qualcomm,18,B";
}
        
/*!
 Name: MFHotKeyItemView > FCompoundView > FImageView

 Description: The image view for the icon of a shortcut key.
 
 Properties: See FImageView.
*/
MFHotKeyItemView > FCompoundView > FImageView {
   bg_visible:      0;
}

/*************************
 6. The Notifications UI
 *************************/

/*!
 Name: #notificationTitleView {

 Description: The text view for the title of the notifications UI.

 Properties:
*/
#notificationTitleView { 
   text_margins:              "2,3,2,3";
   font:                      "Qualcomm,18,B";
   text_color:                #000000;
   bg_image:                  "verizon.bar:vzw_title_bg";
   center_tile:               "188,10,228,20";
}

/*!
 Name: MFNewNotificationView {

 Description: Icon view for new notification animation.

 Properties:
  newnotification_imageN: Nth image in new notification icon animation
*/
MFNewNotificationView {
   newnotification_image1:                "verizon.bar:notification_bright"; 
   newnotification_image2:                "verizon.bar:notification_dimmer"; 
   newnotification_image3:                "verizon.bar:notification_dim"; 
}

MFNotification2DimListView {
   priority_message_image:                "verizon.bar:urgent"; 
}

#notificationScreenView { 
   bg_visible:  1;
   bg_color:    #f1efdc;
}

MFNotificationTableView { 
   bg_visible: 0; 
}

MFNotificationTableView > MFNotification2DimListView { 
   bg_visible:          1; 
   bg_color:            #ffffff;
}

MFNotificationTableView > FInnerListView {
   bg_visible:      0; 
}

MFNotification2DimListView > FScrolledView {
   bg_visible:      0; 
}

MFNotification2DimListView > FScrolledView > FViewport > FCompoundView {
   bg_visible:      0; 
}

FInnerListView > FScrolledView {
   bg_visible:      0; 
}

FInnerListView > FScrolledView > FViewport > FCompoundView {
   bg_visible:      0; 
}

FInnerListView > FScrolledView > FViewport > FCompoundView > MFNotificationMessageView {
   bg_visible:      0; 
}

MFNotification2DimListView > FScrolledView > FViewport > FCompoundView > FInnerListView { 
   bg_visible:      1;
   bg_color:        #000000;
   highlight_color: #ffffff;
}

MFNotificationTableView > FInnerListView > FScrolledView > FViewport > FCompoundView > FTextView {
   v_align:         "512";
   h_align:         "32";
   size:            "0,20";
   bg_visible:      1;
   bg_color:        #e6e6e6;
   text_color:      #000000;
   font:            "Qualcomm,18,B"; 
   border_visible:  1;
   border_color:    #afafaf;
}

MFNotification2DimListView > FScrolledView > FViewport > FCompoundView > FInnerListView > FScrolledView > FViewport > FCompoundView > FTextView {
   v_align:      "512";
   size:         "0,20";
   bg_visible:   0;
}

MFNotification2DimListView > FScrolledView > FViewport > FCompoundView > FInnerListView > FScrolledView > FViewport > FCompoundView > MFNotificationMessageView > FTextView {
   v_align:      "512";
   size:         "0,20";
   bg_visible:   0;
}

#NotificationMsgReadView {
   font:         "Qualcomm,18"; 
}

#NotificationMsgUnreadView {
   font:         "Qualcomm,18,B"; 
}

/***********************
 7. Parental Control UI
************************/

MFPinEntryDialogView {
   bg_visible:              1;
   bg_image:                "verizon.bar:vzw_dialog_bg";
   center_tile:             "50,72,100,73";
}

MFPinEntryDialogView > FCompoundView {
   bg_visible:          0;
}

MFPinEntryDialogView > FCompoundView > FPasswdTextView {
   font:            "Qualcomm,18,B";
}

MFPinEntryDialogView > FDialogTitleView {
   size:            "0,25"; 
}

MFPinEntryDialogView > FDialogTitleView > FTextView { 
   offsets:         "0,10,0,0";
   h_align:         32;
   v_align:         1024;
}

#ratingFilterTitleView { 
   text_margins:        "2,2,2,3";
   font:                "Qualcomm,18,B";
   text_color:          #e6e6e6;
   bg_image:            "verizon.bar:vzw_title_bg";
   center_tile:         "110,0,130,26";
}

#ratingFilterInfoTextView {
   text_margins:                "5,5,5,5";
   font:                        "Qualcomm,18";
   border_visible:              1;
}

MFRatingFilterScreenView > FListView > FScrolledView > FViewport > FCompoundView > FTextView {
   text_margins:                        "5,5,5,5";
   font:                                "Qualcomm,18,B"; 
   text_color:                          #303030; 
   text_color_highlighted:              #153354;
   bg_visible:                          1;   
   bg_color:                            #e6e6e6; 
}

/*************************
 8. The Data Services UI
 *************************/

/*!
 Name: #dataViewerTitleView {

 Description: The text view for the title of the data services UI.

 Properties:
*/
#dataViewerTitleView { 
   text_margins:        "2,2,2,3";
   font:                "Qualcomm,18,B";
   text_color:          #e6e6e6;
   bg_image:            "verizon.bar:vzw_title_bg";
   center_tile:         "110,0,130,26";
}

MFMultiMediaStatusView {
   bg_image:            "verizon.bar:blank";
   center_tile:         "12,12,228,196";
}

MFMultiMediaStatusView > FTextAreaView {
   text_margins:     "5,5,5,5";
   font:             "Qualcomm,18,B";
   text_color:       #e6e6e6;
   bg_visible:       0;   
}

/*************************
 MFAboutDialog
 *************************/

MFAboutDialogView {
   size:                    "200,124";
   bg_visible:              1;
   bg_image:                "verizon.bar:vzw_dialog_bg";
   center_tile:             "50,72,100,73";
}  

MFAboutDialogView > FDialogTitleView {
   size:            "0,25"; 
}

MFAboutDialogView > FDialogTitleView > FTextView { 
   bg_visible:      0;
   size:            "0,25";
   offsets:         "0,0,0,2";
   h_align:         32;
   v_align:         1024;
}

MFAboutDialogView > FCompoundView > FTextAreaView {
   offsets:                "0,4,0,0";
   text_margins:           "4,2,2,2";
   h_align:                32;
   font:                   "Qualcomm,18,B";
   text_color:             #000000;
   bg_visible:             0; 
}

MFAboutDialogView > FCompoundView {
   offsets:             "3,0,3,0";
   bg_visible:          0;
}

MFAboutDialogView > FCompoundView > FScrolledView {
   bg_visible:   0;
}

MFAboutDialogView > FCompoundView > FScrolledTextView { 
   offsets:	     "0,10,0,10";
}

MFAboutDialogView > FCompoundView > FScrolledTextView > FTextAreaView { 
   h_align:          32;
   text_margins:     "4,2,2,2";
   font:             "Qualcomm,18"; 
   text_color:       #000000; 
   bg_visible:       0; 
}
